Equation :math:numref:`calibrationfactor`

.. math::

	f_{\mathrm{calib}}=\frac{V_{\mathrm{calib}}*\chi _{\mathrm{calib}}}{A_{\mathrm{calib}}-A_{\mathrm{blank}}}

* :math:`f_{\mathrm{calib}}`: :term:`Calibration Factor <calib_factor>` 
* :math:`V_{\mathrm{calib}}`: :term:`Volume of calibration gas samples <volume_calib>` 
* :math:`\chi _{\mathrm{calib}}`: :term:`Certified amount fraction of calibration gas <conc_calib>` 
* :math:`A_{\mathrm{calib}}`: :term:`Peak area of calibration gas measurement <area_calib>` 
* :math:`A_{\mathrm{blank}}`: :term:`Possible blank area value determined in zero gas measurements <area_blank>` 

